#!/bin/sh
# This is an install/update script for Debian Design
# Debian Design Homepage: https://wiki.debian.org/Design
# Source of this code: git://git.debian.org/design/blends

set -e

# Administration
#  * include package usage reporting Popularity-Contest
#  * include APT hook apt-listchanges
#  * include APT hook needrestart
#  * include APT package support tracking
# Console
#  * include console compression tools
#  * install console editor GNU nano
#  * include filesystem-related console helper tools
#  * include network-related console helper tools
#  * install console file manager Midnight Commander
# Console-based design tools
#  * include Scour, gtk-vector-screenshot and other SVG tools
#  * include Scrot (SCReen shOT), pngcrush and other bitmap tools
#  * include pdfposter and other PDF tools
# Console media
#  * include core ALSA audio tools
#  * include PulseAudio console tools
# Desktop
#  * include GTK system tools
#  * include GNOME-oriented NetworkManager client
#  * include screensaver unicode-screensaver
# Desktop design
#  * include font tools fontmake, lcdf-typetools and ufo2otf
#  * include webdesign helper tools fontcustom and sassc
#  * include color pickers Gcolor3 and Gpick
#  * include 2D vector-based drawing application Inkscape
#  * include Desktop Publishing application Scribus
#  * include GTK+ font tools
#  * include painting applications Drawing, GIMP and MyPaint, with add-ons
#  * include PDF tools BookletImposer, PDF Arranger and DiffPDF
# Desktop email
#  * include Thunderbird email client
# desktop-environment-xfce
#  * include the lightweight Xfce desktop
#  * include Xfce power management tools
#  * include Xfce file manager
#  * include Xfce notification manager
#  * include Xfce audio handling
# Desktop media
#  * include simple ALSA volume systray icon
#  * include PulseAudio desktop volume control
#  * include video player Mpv
#  * exclude PulseAudio wrapper for legacy audio system EsounD
#  * exclude video player MPlayer2
# Desktop office
#  * include document viewer Evince
#  * include LibreOffice Writer
#  * include LibreOffice Calc
#  * include LibreOffice Impress
#  * exclude LibreOffice Database
#  * include LibreOffice integration with GTK+ 3.x
# Desktop photo
#  * include photo manager Shotwell
# Desktop scheduling
#  * include Thunderbird extension Lightning
# Desktop web
#  * include Firefox web browser
# Package framework
#  * include command-line and Curses APT frontend aptitude
# Hardware
#  * include OpenGL hardware rasterizers
# Audio service
#  * include PulseAudio audio daemon
apt install alsa-utils apt-listchanges aptitude bookletimposer bzip2 cairosvg debian-security-support dfc diffpdf drawing evince firefox-esr font-manager fontcustom fontmake gcolor3 gimp gimp-gmic gimp-lensfun gpick gtk-vector-screenshot gucharmap inkscape jpeginfo jpegoptim lcdf-typetools less libgl1-mesa-dri libpdf-reuse-perl libpodofo-utils libreoffice-calc libreoffice-gtk3 libreoffice-impress libreoffice-writer librsvg2-bin libtiff-tools lightdm lightning links mc mpv mtr-tiny mypaint mypaint-data-extras nano ncdu needrestart network-manager-gnome optipng pasystray pavucontrol pdfarranger pdfposter poppler-utils popularity-contest pulseaudio pulseaudio-utils pulsemixer qpdf rsync sassc scour scribus scrot shotwell slick-greeter thunar thunderbird ufo2otf unicode-screensaver usermode volumeicon-alsa webext-dav4tbsync wget xfce4-notifyd xfce4-panel xfce4-power-manager xfce4-power-manager-plugins xfce4-pulseaudio-plugin xfce4-session xserver-xorg \
 evince-gtk- libreoffice-base- libreoffice-java-common- mplayer2- pulseaudio-esound-compat-

# Administration
#  * define routines to make backup of and help edit config files
# Console
#  * adapt default settings for console file manager Midnight Commander
# desktop-environment-xfce
#  * silence confusing panel question at initial login
#  * replace appfinder with mail-reader in default panel
#  * disable storing session at logout by default
suite=bullseye

apt-mark auto \
  aptitude-common bzip2 pulseaudio-utils sensible-utils xserver-xorg || true
 _backup(){ set -e;\
  if [ -e "$1" ]; then \
    find "$1.orig" -mtime +1 2>/dev/null && ext=bak || ext=orig;\
    cp -a "$1" "$1.$ext";\
  else \
    touch "$1.orig";\
  fi; };\
 _backup_todir(){ set -e;\
  dir="${2:-$(dirname "$1").bak}";\
  [ -e "$dir" ] || mkdir -p "$dir";\
  path="$dir/$(basename "$1")";\
  if [ -e "$1" ]; then \
    cp -fa "$1" "$path";\
  else \
    touch "$path";\
  fi; };\
 _clone(){ set -e;\
  test -e "$1";\
  _backup "$2";\
  cp -fa "$1" "$2"; };\
 _setline(){ set -e;\
  _backup "$1";\
  if [ $# = 3 ]; then \
    if grep -Eq "^$2\$" "$1"; then \
      sed -i -r \
        -e 's!^('"$2"')$!'"$3"'!g' "$1";\
    else \
      sed -i -r \
        -e 's!^#('"$2"')$!'"$3"'!g' "$1";\
    fi;\
  else \
    sed -i -r \
      -e 's!^#?('"$2"')$!\1!g' "$1";\
  fi; };\
 _setappendline(){ set -e;\
  if grep -Eq '^#?'"$2"'$' "$1" 2>/dev/null; then \
    _setline "$@";\
  else \
    _backup "$1";\
    echo "${3:-$2}" >> "$1";\
  fi; };\
 _setvar(){ set -e;\
  _backup "$1";\
  if grep -Eq '^'"$2"'[ \t]*=' "$1"; then \
    sed -i -r \
      -e 's!^('"$2"'[ \t]*=[ \t]*).*!\1'"$3"'!' "$1";\
  else \
    sed -i -r \
      -e 's!^#('"$2"'[ \t]*=[ \t]*).*!\1'"$3"'!' "$1";\
  fi; };\
 _setappendvar(){ set -e;\
  if grep -Eq '^#?'"$2"'[ \t]*=' "$1" 2>/dev/null; then \
    _setvar "$@";\
  else \
    _backup "$1";\
    echo "$2=$3" >> "$1";\
  fi; };\
 _setinivar(){ set -e;\
  _backup "$1";\
  if sed -ne '/^\['"$2"'\]/,/^\[.*\]/ p' "$1" | grep -Eq '^'"$3"'[ \t]*='; then \
    sed -i -r \
      -e '/^\['"$2"'\]/,/^\[.*\]/ s!^('"$3"'[ \t]*=[ \t]*).*$!\1'"$4"'!' "$1";\
  else \
    sed -i -r \
      -e '/^\['"$2"'\]/,/^\[.*\]/ s!^#('"$3"'[ \t]*=[ \t]*).*$!\1'"$4"'!' "$1";\
  fi; };\
 _clearinikey(){ set -e;\
  _backup "$1";\
  if sed -ne '/^\['"$2"'\]/,/^\[.*\]/ p' "$1" | grep -Eq '^'"$3"'[ \t]*='; then \
    sed -i -r \
      -e '/^\['"$2"'\]/,/^\[.*\]/ s!^('"$3"'[ \t]*=[ \t]*).*$!\1'"$4"'!' "$1";\
  else \
    sed -i -r \
      -e '/^\['"$2"'\]/,/^\[.*\]/ s!^#('"$3"'[ \t]*=[ \t]*).*$!\1'"$4"'!' "$1";\
  fi; };\
 _setaddinivar(){ set -e;\
  _backup "$1";\
  if [ ! -e "$1" ]; then \
    { echo "[$2]"; echo "$3=$4"; } >> "$1";\
  elif ! grep -Eq "^\\[$2\\]" "$1"; then \
    { echo; echo "[$2]"; echo "$3=$4"; } >> "$1";\
  elif sed -ne '/^\['"$2"'\]/,/^\[.*\]/ p' "$1" | grep -Eq '^#?'"$3"'[ \t]*='; then \
    _setinivar "$@";\
  else \
    sed -i -r \
      -e '/^\['"$2"'\]/ a'"$3=$4" "$1";\
  fi; };\
 _uuid(){ set -e;\
  tmpfile=$(mktemp);\
  (umask 077; fallocate --length 40kib "$tmpfile");\
  PATH="/usr/sbin:/sbin:$PATH" mkswap "$tmpfile" | grep -Po '\bUUID=\K\S+';\
  rm -f "$tmpfile"; };\
 file=/etc/mc/mc.ini;\
 _setaddinivar "$file" Midnight-Commander auto_save_setup false;\
 _setaddinivar "$file" Midnight-Commander use_internal_view true;\
 _setaddinivar "$file" Midnight-Commander use_internal_edit true;\
 _setaddinivar "$file" Midnight-Commander num_history_items_recorded 200;\
 _setaddinivar "$file" Midnight-Commander editor_option_save_mode false;\
 _setaddinivar "$file" Midnight-Commander editor_show_right_margin false;\
 _setaddinivar "$file" Midnight-Commander skin dark;\
 _setaddinivar "$file" Panels navigate_with_arrows true;\
 _setaddinivar "$file" Layout message_visible false;\
 _setaddinivar "$file" Layout menubar_visible false;\
 cd /etc/xdg/xfce4/xfconf/xfce-perchannel-xml;\
 _clone ../../panel/default.xml xfce4-panel.xml;\
 sed -i -r \
  -e 's,xfce4-appfinder,exo-mail-reader,' \
  xfce4-panel.xml;\
 _backup xfce4-session.xml;\
 sed -i -r \
  -e 's,(<property name="general"[^>]*>),\1\n    <property name="SaveOnExit" type="bool" value="false"/>,' \
  xfce4-session.xml
